DwmPlatform class abstract
- Inheritance
-
- Object
- PlatformInterface
- DwmPlatform
- Implementers
Constructors
- DwmPlatform()
- Constructs a DwmPlatform.
Properties
-
getColorScheme
→ Future<
DwmColorScheme> -
no setter
-
getContentProtection
→ Future<
DwmDisplayAffinity> -
no setter
-
getPlatformVersion
→ Future<
DwmPlatformVersion> -
no setter
-
getThemeMode
→ Future<
DwmThemeMode> -
no setter
-
getWindowMaxSize
→ Future<
Size> -
no setter
-
getWindowMinSize
→ Future<
Size> -
no setter
-
getWindowSize
→ Future<
Size> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
isWindowClosable
→ Future<
bool> -
no setter
-
isWindowMaximizable
→ Future<
bool> -
no setter
-
isWindowMaximized
→ Future<
bool> -
no setter
-
isWindowMinimizable
→ Future<
bool> -
no setter
-
isWindowMinimized
→ Future<
bool> -
no setter
-
isWindowResizable
→ Future<
bool> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
DwmListener listener) → void -
ensureInitialized(
) → Future< bool> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeListener(
DwmListener listener) → void -
resetWindowMaxSize(
) → Future< void> -
resetWindowMinSize(
) → Future< void> -
setColorScheme(
DwmColorScheme colorScheme) → Future< void> -
setContentProtection(
DwmDisplayAffinity value) → Future< void> -
setThemeMode(
DwmThemeMode themeMode) → Future< void> -
setWindowCation(
String caption) → Future< void> -
setWindowClosable(
bool closable) → Future< void> -
setWindowCornerPreference(
DwmWindowCornerPreference value) → Future< void> -
setWindowIconAndCationVisibility(
bool visibility) → Future< void> -
setWindowMaximizable(
bool maximizable) → Future< void> -
setWindowMaximized(
) → Future< void> -
setWindowMaxSize(
Size size) → Future< void> -
setWindowMinimizable(
bool minimizable) → Future< void> -
setWindowMinimized(
) → Future< void> -
setWindowMinSize(
Size size) → Future< void> -
setWindowResizable(
bool resizable) → Future< void> -
setWindowRestore(
) → Future< void> -
setWindowSize(
Size size) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
-
triggerSnapLayouts(
) → Future< void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ DwmPlatform
-
The default instance of DwmPlatform to use.
getter/setter pair